@@ -62,7 +62,7 @@ define('CGCALENDAR_PREF_DFLTMYEVENTS_TEMPLATE','cgcalendar_pref_dfltmyevents_tem
 define('CGCALENDAR_PREF_NEWEDITEVENT_TEMPLATE','cgcalendar_pref_neweditevent_template');
 define('CGCALENDAR_PREF_DFLTEDITEVENT_TEMPLATE','cgcalendar_pref_dflteditevent_template');
 
-class CGCalendar extends CGExtensions
+final class CGCalendar extends CGExtensions
 {
   var $categories_table_name;
   var $events_to_categories_table_name;
@@ -72,79 +72,71 @@ class CGCalendar extends CGExtensions
   var $admin_tools_loaded;
   
   function __construct()
-    {
-      parent::__construct();
-      
-      $this->categories_table_name = cms_db_prefix() . 'module_cgcalendar_categories';
-      $this->events_to_categories_table_name = cms_db_prefix().'module_cgcalendar_events_to_categories';
-      $this->events_table_name = cms_db_prefix().'module_cgcalendar_events';
-      $this->event_field_values_table_name = cms_db_prefix() . 'module_cgcalendar_event_field_values';
-      $this->fields_table_name = cms_db_prefix() . 'module_cgcalendar_fields';
-      $this->admin_tools_loaded = false;
-    }
-
-  function SetParameters()
-    {
-      $this->RegisterModulePlugin();
-      $this->RestrictUnknownParams();
-      
-      $this->SetParameterType('day',CLEAN_INT);
-
-      $this->SetParameterType('display',CLEAN_STRING);
-      $this->SetParameterType('category',CLEAN_STRING);
-      $this->SetParameterType('month',CLEAN_INT);
-      $this->SetParameterType('year',CLEAN_INT);
-      $this->SetParameterType('first_day_of_week',CLEAN_INT);
-      $this->SetParameterType('use_session',CLEAN_STRING);
-      $this->SetParameterType('inline',CLEAN_INT);
-	  $this->SetParameterType('reverse',CLEAN_STRING);
-      $this->SetParameterType('detailpage',CLEAN_STRING);
-      $this->SetParameterType('columns',CLEAN_INT);
-      $this->SetParameterType('columnstyle',CLEAN_STRING);
-      $this->SetParameterType('currentcolumn',CLEAN_INT);
-
-	  $this->SetParameterType('page',CLEAN_INT);
-      $this->SetParameterType('event_id',CLEAN_INT);
-      $this->SetParameterType('limit',CLEAN_INT);
-	  $this->SetParameterType('detail',CLEAN_STRING);
-      $this->SetParameterType('calendartemplate',CLEAN_STRING);
-      $this->SetParameterType('eventtemplate',CLEAN_STRING);
-      $this->SetParameterType('listtemplate',CLEAN_STRING);
-      $this->SetParameterType('upcominglisttemplate',CLEAN_STRING);
-	  $this->SetParameterType('searchtemplate',CLEAN_STRING); // todo, doc this.
-	  $this->SetParameterType('searchresulttemplate',CLEAN_STRING); // todo, doc this.
-	  $this->SetParameterType('searchresultpage',CLEAN_STRING); // todo, doc this
-	  $this->SetParameterType('displayforday',CLEAN_INT);
-
-	  $this->SetParameterType('myeventstemplate',CLEAN_STRING); 
-	  $this->SetParameterType('editeventtemplate',CLEAN_STRING); 
-      $this->SetParameterType('editpage',CLEAN_INT);
-
-	  $this->SetParameterType('unique_only',CLEAN_INT);
-
-      $this->SetParameterType('return_id',CLEAN_INT);
-      $this->SetParameterType('return_link',CLEAN_STRING);
-
-	  $this->SetParameterType('show_ical',CLEAN_STRING);
-      
-	  $this->SetParameterType(CLEAN_REGEXP.'/cal_.*/',CLEAN_STRING);
-
-      $this->RegisterRoute('/'.$this->GetPreference('url_prefix','calendar').'\/(?P<returnid>[0-9]+)\/(?P<event_id>[0-9]+)-.*$/',
-			   array('action'=>'default',
-				 'display'=>'event'));
-
-	  if( version_compare(CMS_VERSION,'1.10-beta0') < 0 )
-		{
-		  $this->InitializeAdmin();
-		}
-    }
-  
-
-  function InitializeFrontend()
   {
-	$this->SetParameters();
+	parent::__construct();
+      
+	$this->categories_table_name = cms_db_prefix() . 'module_cgcalendar_categories';
+	$this->events_to_categories_table_name = cms_db_prefix().'module_cgcalendar_events_to_categories';
+	$this->events_table_name = cms_db_prefix().'module_cgcalendar_events';
+	$this->event_field_values_table_name = cms_db_prefix() . 'module_cgcalendar_event_field_values';
+	$this->fields_table_name = cms_db_prefix() . 'module_cgcalendar_fields';
+	$this->admin_tools_loaded = false;
   }
 
+  function SetParameters()
+  {
+	$this->RegisterModulePlugin();
+	$this->RestrictUnknownParams();
+
+	$this->SetParameterType('day',CLEAN_INT);
+
+	$this->SetParameterType('display',CLEAN_STRING);
+	$this->SetParameterType('category',CLEAN_STRING);
+	$this->SetParameterType('month',CLEAN_INT);
+	$this->SetParameterType('year',CLEAN_INT);
+	$this->SetParameterType('first_day_of_week',CLEAN_INT);
+	$this->SetParameterType('use_session',CLEAN_STRING);
+	$this->SetParameterType('inline',CLEAN_INT);
+	$this->SetParameterType('reverse',CLEAN_STRING);
+	$this->SetParameterType('detailpage',CLEAN_STRING);
+	$this->SetParameterType('columns',CLEAN_INT);
+	$this->SetParameterType('columnstyle',CLEAN_STRING);
+	$this->SetParameterType('currentcolumn',CLEAN_INT);
+
+	$this->SetParameterType('page',CLEAN_INT);
+	$this->SetParameterType('event_id',CLEAN_INT);
+	$this->SetParameterType('limit',CLEAN_INT);
+	$this->SetParameterType('detail',CLEAN_STRING);
+	$this->SetParameterType('calendartemplate',CLEAN_STRING);
+	$this->SetParameterType('eventtemplate',CLEAN_STRING);
+	$this->SetParameterType('listtemplate',CLEAN_STRING);
+	$this->SetParameterType('upcominglisttemplate',CLEAN_STRING);
+	$this->SetParameterType('searchtemplate',CLEAN_STRING); // todo, doc this.
+	$this->SetParameterType('searchresulttemplate',CLEAN_STRING); // todo, doc this.
+	$this->SetParameterType('searchresultpage',CLEAN_STRING); // todo, doc this
+	$this->SetParameterType('displayforday',CLEAN_INT);
+
+	$this->SetParameterType('myeventstemplate',CLEAN_STRING); 
+	$this->SetParameterType('editeventtemplate',CLEAN_STRING); 
+	$this->SetParameterType('editpage',CLEAN_INT);
+
+	$this->SetParameterType('unique_only',CLEAN_INT);
+
+	$this->SetParameterType('return_id',CLEAN_INT);
+	$this->SetParameterType('return_link',CLEAN_STRING);
+
+	$this->SetParameterType('show_ical',CLEAN_STRING);
+      
+	$this->SetParameterType(CLEAN_REGEXP.'/cal_.*/',CLEAN_STRING);
+
+	$this->RegisterRoute('/'.$this->GetPreference('url_prefix','calendar').'\/(?P<returnid>[0-9]+)\/(?P<event_id>[0-9]+)-.*$/',
+						 array('action'=>'default','display'=>'event'));
+
+	if( version_compare(CMS_VERSION,'1.10-beta0') < 0 ) {
+	  $this->InitializeAdmin();
+	}
+  }
+  
 
   function InitializeAdmin()
   {
@@ -153,23 +145,29 @@ class CGCalendar extends CGExtensions
 	$this->CreateParameter('editpage','',$this->Lang('help_param_editpage'));
   }
 
-  public function LazyLoadFrontend()
-  {
-	return FALSE;
-  }
-
-
-  public function LazyLoadAdmin()
-  {
-	return TRUE;
-  }
-
-
-  function GetName()
-  {
-	return 'CGCalendar';
-  }
-  
+  function InitializeFrontend() { $this->SetParameters(); }
+  function GetName() { return 'CGCalendar'; }
+  function GetAuthor() { return 'Rob Allen/Calguy1000/Morten Poulsen'; }
+  function GetAuthorEmail() { return 'morten@poulsen.org/calguy1000@hotmail.com'; }
+  function IsPluginModule() { return true; }
+  function HasAdmin() { return true; }  
+  function GetEventDescription( $eventname ) { return $this->lang('eventdesc-' . $eventname); }
+  function GetEventHelp( $eventname ) {	return $this->lang('eventhelp-' . $eventname); }
+  function GetVersion() { return '1.10.4'; }
+  function GetDependencies() { return array('CGExtensions'=>'1.32'); }
+  function GetDescription($lang = 'en_US') { return $this->Lang("description"); }
+  function GetAdminDescription() { return $this->Lang('cal_description'); }
+  function GetAdminSection() { return 'content'; }
+  function GetHelp () { return file_get_contents(__DIR__.'/help.inc'); }
+  function MinimumCMSVersion() { return '1.11.3'; }
+  function GetChangeLog() { return file_get_contents(__DIR__.'/changelog.inc'); }
+  function InstallPostMessage() { return $this->Lang('install_postmessage'); }
+  function UninstallPreMessage() { return $this->Lang('areyousure_uninstall'); }
+  function AllowAutoInstall() { return FALSE; }
+  function AllowAutoUpgrade() { return FALSE; }
+  function UninstallPostMessage() {	return $this->Lang('post_uninstall'); }
+  public function LazyLoadFrontend() { return FALSE; }
+  public function LazyLoadAdmin() { return TRUE; }
 
   function GetFriendlyName()
   {
@@ -178,260 +176,141 @@ class CGCalendar extends CGExtensions
 	return $tmp;
   }
   
-  function GetAuthor()
-  {
-	return 'Rob Allen/Calguy1000/Morten Poulsen';
-  }
-  
-  function GetAuthorEmail()
-    {
-      return 'morten@poulsen.org/calguy1000@hotmail.com';
-    }
-  
-  function IsPluginModule()
-    {
-      return true;
-    }
-  
-  function HasAdmin()
-    {
-      return true;
-    }
-  
   function VisibleToAdminUser()
-    {
-      return $this->CheckPermission('Modify Calendar') ||
-		$this->CheckPermission('Manage Calendar Attributes') ||
-		$this->CheckPermission('Modify Site Preferences') ||
-		$this->CheckPermission('Modify Templates');
-    }
-  
-  function GetEventDescription( $eventname )
-    {
-      return $this->lang('eventdesc-' . $eventname);
-    }
-
-  function GetEventHelp( $eventname )
-    {
-      return $this->lang('eventhelp-' . $eventname);
-    }
-
-  function GetVersion()
-    {
-      return '1.10.2';
-    }
-
-  function GetDependencies()
-    {
-      return array('CGExtensions'=>'1.31');
-    }
-
-  function GetDescription($lang = 'en_US')
-    {
-      return $this->Lang("description");
-    }
-
-  function GetAdminDescription()
-    {
-      return $this->Lang('cal_description');
-    }
-
-  function GetAdminSection()
-    {
-      return 'content';
-    }
-
-  function GetHelp ()
-    {
-	  return file_get_contents(dirname(__FILE__).'/help.inc');
-    }
-
-  function MinimumCMSVersion()
-    {
-      return '1.11.2';
-    }
-
-  function GetChangeLog()
-    {
-      return file_get_contents(dirname(__FILE__).'/changelog.inc');
-    }
-
-  function InstallPostMessage()
-    {
-      return $this->Lang('install_postmessage');
-    }
-
-  function UninstallPreMessage()
   {
-	return $this->Lang('areyousure_uninstall');
-  }
-
-  function UninstallPostMessage()
-  {
-	return $this->Lang('post_uninstall');
+	return $this->CheckPermission('Modify Calendar') ||
+	  $this->CheckPermission('Manage Calendar Attributes') ||
+	  $this->CheckPermission('Modify Site Preferences') ||
+	  $this->CheckPermission('Modify Templates');
   }
 
   function GetEvent($event_id)
-    {
-      $db = $this->GetDb(); /* @var $db ADOConnection */
+  {
+	$db = $this->GetDb(); /* @var $db ADOConnection */
 
-      $sql = 'SELECT * FROM ' . $this->events_table_name .' WHERE event_id = ?';
-      $rs = $db->Execute($sql,array($event_id));
-      if($rs && $rs->RecordCount() > 0)
-		{
-		  $result = $rs->FetchRow();
-		  $result['event_date_start_ut'] = $db->UnixTimeStamp($result['event_date_start']);
-		  if( is_null($result['event_date_end']) || $result['event_date_end'] == '0000-00-00 00:00:00')
-			{
-			  $result['event_date_end'] = NULL;
-			}
-		  $result['event_date_end_ut'] = $db->UnixTimeStamp($result['event_date_end']);
-		  if( is_null($result['event_date_recur_end']) || $result['event_date_recur_end'] == '0000-00-00 00:00:00' )
-			{
-			  $result['event_date_recur_end'] = NULL;
-			}
-		  $result['event_date_recur_end_ut'] = $db->UnixTimeStamp($result['event_date_recur_end']);
-		  $result['event_recur_count'] = $result['event_recur_nevents'];
-		  $result['event_recur_weekdays'] = explode(',',$result['event_recur_weekdays']);
-		  $result['event_recur_monthdays'] = explode(',',$result['event_recur_monthdays']);
-		  $result['categories'] = array();
+	$sql = 'SELECT * FROM ' . $this->events_table_name .' WHERE event_id = ?';
+	$rs = $db->Execute($sql,array($event_id));
+	if($rs && $rs->RecordCount() > 0) {
+	  $result = $rs->FetchRow();
+	  $result['event_date_start_ut'] = $db->UnixTimeStamp($result['event_date_start']);
+	  if( is_null($result['event_date_end']) || $result['event_date_end'] == '0000-00-00 00:00:00') {
+		$result['event_date_end'] = NULL;
+	  }
+	  $result['event_date_end_ut'] = $db->UnixTimeStamp($result['event_date_end']);
+	  if( is_null($result['event_date_recur_end']) || $result['event_date_recur_end'] == '0000-00-00 00:00:00' ) {
+		$result['event_date_recur_end'] = NULL;
+	  }
+	  $result['event_date_recur_end_ut'] = $db->UnixTimeStamp($result['event_date_recur_end']);
+	  $result['event_recur_count'] = $result['event_recur_nevents'];
+	  $result['event_recur_weekdays'] = explode(',',$result['event_recur_weekdays']);
+	  $result['event_recur_monthdays'] = explode(',',$result['event_recur_monthdays']);
+	  $result['categories'] = array();
 
-		  // now pick up categories
-		  $sql = 'SELECT category_id FROM ' . $this->events_to_categories_table_name . ' WHERE event_id = ?';
-		  $rs = $db->Execute($sql,array($event_id));
-		  if($rs)
-			{
-			  while($row = $rs->FetchRow())
-				{
-				  $result['categories'][] = $row['category_id'];
-				}
-			}
-		  
-		  // now pick up the custom fields
-		  $result['fields'] = array();
-		  $sql = 'SELECT field_name, field_value FROM ' . $this->event_field_values_table_name . ' WHERE event_id = ?';
-		  $rs = $db->Execute($sql,array($event_id));
-		  if($rs)
-			{
-			  while($row = $rs->FetchRow())
-				{
-				  $result['fields'][$row['field_name']] = $row['field_value'];
-				}
-			}
-
-		  // test if this is an all day event.
-		  // cuz we don't store that info in the database.
-		  $sd = date('z',$result['event_date_start_ut']);
-		  $sh = date('G',$result['event_date_start_ut']);
-		  $sm = date('i',$result['event_date_start_ut']);
-		  $ed = date('z',$result['event_date_end_ut']);
-		  $eh = date('G',$result['event_date_end_ut']);
-		  $em = date('i',$result['event_date_end_ut']);
-		  $result['all_day_event'] = 0;
-		  $result['alt_end_date'] = 0;
-		  if( $sh == 0 && $sm == 0 && $eh == 23 && $em == 59 )
-			{
-			  $result['all_day_event'] = 1;
-			}
-		  if( $sd != $ed )
-			{
-			  $result['alt_end_date'] = 1;
-			}
+	  // now pick up categories
+	  $sql = 'SELECT category_id FROM ' . $this->events_to_categories_table_name . ' WHERE event_id = ?';
+	  $rs = $db->Execute($sql,array($event_id));
+	  if($rs) {
+		while($row = $rs->FetchRow()) {
+		  $result['categories'][] = $row['category_id'];
 		}
-      else
-		{
-		  // create an empty record
-		  $result = array();
-		  $result['event_id'] = -1;
-		  $result['event_title'] = '';
-		  $result['event_summary'] = '';
-		  $result['event_details'] = '';
-		  $result['event_date_start'] = NULL;
-		  $result['event_date_end'] = NULL;
-		  $result['event_date_start_ut'] = strtotime($this->GetPreference('dflt_starttime'));
-		  $result['event_date_end_ut'] = NULL;
-		  $result['event_created_by'] = -1;
-		  $result['event_create_date'] = NULL;
-		  $result['event_modified_date'] = NULL;
-		  $result['event_recur_period'] = 'none';
-		  $result['event_date_recur_end_ut'] = NULL;
-		  $result['event_date_recur_end'] = NULL;
-		  $result['event_recur_interval'] = -1;
-		  $result['event_parent_id'] = -1;
-		  $result['event_recur_count'] = -1;
-		  $result['event_recur_weekdays'] = array();
-		  $result['event_recur_monthdays'] = array();
-		  $result['event_allows_overlap'] = 1; // default to yes.
-		  $result['categories'] = array();
-		  $result['fields'] = array();
-		  $result['all_day_event'] = $this->GetPreference('dflt_alldayevent');
-		  $result['alt_end_date'] = 0;
+	  }
+
+	  // now pick up the custom fields
+	  $result['fields'] = array();
+	  $sql = 'SELECT field_name, field_value FROM ' . $this->event_field_values_table_name . ' WHERE event_id = ?';
+	  $rs = $db->Execute($sql,array($event_id));
+	  if($rs) {
+		while($row = $rs->FetchRow()) {
+		  $result['fields'][$row['field_name']] = $row['field_value'];
 		}
+	  }
+
+	  // test if this is an all day event.
+	  // cuz we don't store that info in the database.
+	  $sd = date('z',$result['event_date_start_ut']);
+	  $sh = date('G',$result['event_date_start_ut']);
+	  $sm = date('i',$result['event_date_start_ut']);
+	  $ed = date('z',$result['event_date_end_ut']);
+	  $eh = date('G',$result['event_date_end_ut']);
+	  $em = date('i',$result['event_date_end_ut']);
+	  $result['all_day_event'] = 0;
+	  $result['alt_end_date'] = 0;
+	  if( $sh == 0 && $sm == 0 && $eh == 23 && $em == 59 ) {
+		$result['all_day_event'] = 1;
+	  }
+	  if( $sd != $ed ) {
+		$result['alt_end_date'] = 1;
+	  }
+	}
+	else {
+	  // create an empty record
+	  $result = array();
+	  $result['event_id'] = -1;
+	  $result['event_title'] = '';
+	  $result['event_summary'] = '';
+	  $result['event_details'] = '';
+	  $result['event_date_start'] = NULL;
+	  $result['event_date_end'] = NULL;
+	  $result['event_date_start_ut'] = strtotime($this->GetPreference('dflt_starttime'));
+	  $result['event_date_end_ut'] = NULL;
+	  $result['event_created_by'] = -1;
+	  $result['event_create_date'] = NULL;
+	  $result['event_modified_date'] = NULL;
+	  $result['event_recur_period'] = 'none';
+	  $result['event_date_recur_end_ut'] = NULL;
+	  $result['event_date_recur_end'] = NULL;
+	  $result['event_recur_interval'] = -1;
+	  $result['event_parent_id'] = -1;
+	  $result['event_recur_count'] = -1;
+	  $result['event_recur_weekdays'] = array();
+	  $result['event_recur_monthdays'] = array();
+	  $result['event_allows_overlap'] = 1; // default to yes.
+	  $result['categories'] = array();
+	  $result['fields'] = array();
+	  $result['all_day_event'] = $this->GetPreference('dflt_alldayevent');
+	  $result['alt_end_date'] = 0;
+	}
 	  
-      return $result;
-    }
+	return $result;
+  }
 
 
   function GetEventFromParams(&$event,$params,$is_edit = false)
-    {
+  {
 	  $db = $this->GetDb();
-	  if( isset($params['event_id']) )
-		{
-		  $event['event_id'] =  (int)$params['event_id'];
-		}
-	  if( isset($params['event_parent_id']) )
-		{
-		  $event['event_parent_id'] = (int)$params['event_parent_id'];
-		}
-	  if( isset($params['event_title']) )
-		{
-		  $event['event_title'] = trim($params['event_title']);
-		}
-	  if( isset($params['event_summary']) )
-		{
-		  $event['event_summary'] = trim($params['event_summary']);
-		}
-	  if( isset($params['event_details']) )
-		{
-		  $event['event_details'] = trim($params['event_details']);
-		}
-	  
-	  if( isset($params['event_allows_overlap']) )
-		{
-		  $event['event_allows_overlap'] = (int)$params['event_allows_overlap'];
-		}
-	  else
-		{
-	      $tmp = $this->GetPreference('overlap_policy','all');
-		  $event['event_allows_overlap'] = ($tmp == 'all')?1:0;
-		}
+	  if( isset($params['event_id']) )  $event['event_id'] =  (int)$params['event_id'];
+	  if( isset($params['event_parent_id']) )  $event['event_parent_id'] = (int)$params['event_parent_id'];
+	  if( isset($params['event_title']) )  $event['event_title'] = trim($params['event_title']);
+	  if( isset($params['event_summary']) )  $event['event_summary'] = trim($params['event_summary']);
+	  if( isset($params['event_details']) )  $event['event_details'] = trim($params['event_details']);
+	  if( isset($params['event_allows_overlap']) ) {
+		$event['event_allows_overlap'] = (int)$params['event_allows_overlap'];
+	  }
+	  else {
+		$tmp = $this->GetPreference('overlap_policy','all');
+		$event['event_allows_overlap'] = ($tmp == 'all')?1:0;
+	  }
 
 	  $all_day_event = 0;
-	  if( isset($params['all_day_event']) )
-		{
-		  $all_day_event = (int)$params['all_day_event'];
-		}
+	  if( isset($params['all_day_event']) )  $all_day_event = (int)$params['all_day_event'];
 	  $event['all_day_event'] = $all_day_event;
 
 	  $start_hour = 0;
 	  $start_minute = 0;
-	  if( isset($params['startdate_Month']) )
-		{
-		  if( !$all_day_event )
-			{
-			  $start_hour = $params['startdate_Hour'];
-			  $start_minute = $params['startdate_Minute'];
-			  if( isset($params['startdate_Meridian']) && $params['startdate_Meridian'] == 'pm' &&
-				  $start_hour < 12)
-				{
-				  $start_hour += 12;
-				}
-			}
-		  $event['event_date_start_ut'] = mktime($start_hour,$start_minute,0,
-												 $params['startdate_Month'],$params['startdate_Day'],
-												 $params['startdate_Year']);
-		  $event['event_date_start'] = $db->DbTimeStamp($event['event_date_start_ut']);
+	  if( isset($params['startdate_Month']) ) {
+		if( !$all_day_event ) {
+		  $start_hour = $params['startdate_Hour'];
+		  $start_minute = $params['startdate_Minute'];
+		  if( isset($params['startdate_Meridian']) && $params['startdate_Meridian'] == 'pm' &&
+			  $start_hour < 12) {
+			$start_hour += 12;
+		  }
 		}
+		$event['event_date_start_ut'] = mktime($start_hour,$start_minute,0,
+											   $params['startdate_Month'],$params['startdate_Day'],
+											   $params['startdate_Year']);
+		$event['event_date_start'] = $db->DbTimeStamp($event['event_date_start_ut']);
+	  }
 
 	  $end_hour = 23;
 	  $end_minute = 59;
@@ -440,99 +319,80 @@ class CGCalendar extends CGExtensions
 	  $end_year = $params['startdate_Year'];
 	  $event['event_date_end'] = NULL;
 	  $event['event_date_end_ut'] = NULL;
-	  if( isset($params['enddate_valid']) && isset($params['enddate_Day']) )
-		{
-		  if( !$all_day_event )
-			{
-			  $end_hour = $params['enddate_Hour'];
-			  $end_minute = $params['enddate_Minute'];
+	  if( isset($params['enddate_valid']) && isset($params['enddate_Day']) ) {
+		if( !$all_day_event ) {
+		  $end_hour = $params['enddate_Hour'];
+		  $end_minute = $params['enddate_Minute'];
 
-			  if( isset($params['enddate_Meridian']) && $params['enddate_Meridian'] == 'pm' &&
-				  $end_hour < 12 )
-				{
-				  $end_hour += 12;
-				}
-			}
-
-		  $end_month = $params['enddate_Month'];
-		  $end_day = $params['enddate_Day'];
-		  $end_year = $params['enddate_Year'];
-
-		  $event['event_date_end_ut'] = mktime($end_hour,$end_minute,0,
-											   $end_month,$end_day,$end_year);
-		  $event['event_date_end'] = $db->DbTimeStamp($event['event_date_end_ut']);
-		}
-	  else if( isset($params['all_day_event']) && !isset($params['enddate_valid']) )
-		{
-		  $event['event_date_end_ut'] = mktime($end_hour,$end_minute,0,
-											   $end_month,$end_day,$end_year);
-		  $event['event_date_end'] = $db->DbTimeStamp($event['event_date_end_ut']);
+		  if( isset($params['enddate_Meridian']) && $params['enddate_Meridian'] == 'pm' &&
+			  $end_hour < 12 ) {
+			$end_hour += 12;
+		  }
 		}
 
-	  if( isset($params['event_recur_period']) )
-		{
-		  $event['event_recur_period'] = trim($params['event_recur_period']);
+		$end_month = $params['enddate_Month'];
+		$end_day = $params['enddate_Day'];
+		$end_year = $params['enddate_Year'];
+
+		$event['event_date_end_ut'] = mktime($end_hour,$end_minute,0,
+											 $end_month,$end_day,$end_year);
+		$event['event_date_end'] = $db->DbTimeStamp($event['event_date_end_ut']);
+	  }
+	  else if( isset($params['all_day_event']) && !isset($params['enddate_valid']) ) {
+		$event['event_date_end_ut'] = mktime($end_hour,$end_minute,0,
+											 $end_month,$end_day,$end_year);
+		$event['event_date_end'] = $db->DbTimeStamp($event['event_date_end_ut']);
+	  }
+
+	  if( isset($params['event_recur_period']) ) {
+		$event['event_recur_period'] = trim($params['event_recur_period']);
+	  }
+	  if( isset($params['event_recur_interval']) ) {
+		$event['event_recur_interval'] = (int)$params['event_recur_interval'];
+	  }
+	  if( isset($params['event_recur_weekdays']) ) {
+		if( is_array($params['event_recur_weekdays']) ) {
+		  $event['event_recur_weekdays'] = $params['event_recur_weekdays'];
 		}
-	  if( isset($params['event_recur_interval']) )
-		{
-		  $event['event_recur_interval'] = (int)$params['event_recur_interval'];
+		else {
+		  $event['event_recur_weekdays'] = explode(',',$params['event_recur_weekdays']);
 		}
-	  if( isset($params['event_recur_weekdays']) )
-		{
-		  if( is_array($params['event_recur_weekdays']) )
-			{
-			  $event['event_recur_weekdays'] = $params['event_recur_weekdays'];
-			}
-		  else
-			{
-			  $event['event_recur_weekdays'] = explode(',',$params['event_recur_weekdays']);
-			}
+	  }
+	  if( isset($params['event_recur_monthdays']) ) {
+		if( is_array($params['event_recur_monthdays']) ) {
+		  $event['event_recur_monthdays'] = $params['event_recur_monthdays'];
 		}
-	  if( isset($params['event_recur_monthdays']) )
-		{
-		  if( is_array($params['event_recur_monthdays']) )
-			{
-			  $event['event_recur_monthdays'] = $params['event_recur_monthdays'];
-			}
-		  else
-			{
-			  $event['event_recur_monthdays'] = explode(',',$params['event_recur_monthdays']);
-			}
+		else {
+		  $event['event_recur_monthdays'] = explode(',',$params['event_recur_monthdays']);
 		}
-	  if( isset($params['event_recur_count']) )
-		{
-		  $event['event_recur_count'] = (int)$params['event_recur_count'];
-		}
-	  if( isset($params['event_recur_date_Month']) && $params['event_recur_period'] != 'none' )
-		{
-		  $event['event_date_recur_end_ut'] = mktime(0,0,0,
-													 $params['event_recur_date_Month'],$params['event_recur_date_Day'],$params['event_recur_date_Year']);
-		  $event['event_date_recur_end'] = $db->DbTimeStamp($event['event_date_recur_end_ut']);
-		}
-	  else
-		{
-		  $event['event_date_recur_end'] = NULL;
-		  $event['event_date_recur_end_ut'] = NULL;
-		}
-	}
+	  }
+	  if( isset($params['event_recur_count']) )  $event['event_recur_count'] = (int)$params['event_recur_count'];
+	  if( isset($params['event_recur_date_Month']) && $params['event_recur_period'] != 'none' ) {
+		$event['event_date_recur_end_ut'] = mktime(0,0,0,
+												   $params['event_recur_date_Month'],$params['event_recur_date_Day'],
+												   $params['event_recur_date_Year']);
+		$event['event_date_recur_end'] = $db->DbTimeStamp($event['event_date_recur_end_ut']);
+	  }
+	  else {
+		$event['event_date_recur_end'] = NULL;
+		$event['event_date_recur_end_ut'] = NULL;
+	  }
+  }
 
 
   function GetCategories($order_by='category_order, category_name')
-    {
+  {
       $db = $this->GetDb(); /* @var $db ADOConnection */
       $categories_table_name = $this->categories_table_name;
       $sql = "SELECT * FROM $categories_table_name";
-      if($order_by != '')
-		{
-		  $sql .= " ORDER BY $order_by";
-		}
+      if($order_by != '') $sql .= " ORDER BY $order_by";
 	  
       $result = array();
       $rs = $db->Execute($sql);
       if($rs && $rs->RecordCount() > 0)
 		$result = $rs->GetArray();
       return $result;
-    }
+  }
 
   function GetCategoryName($id)
   {
@@ -617,7 +477,7 @@ class CGCalendar extends CGExtensions
   }
 	
   function AdminUpdateField($field_oldname,$field_newname,$field_type = 0,$field_searchable = 0,$field_extra = '')
-    {
+  {
       $db = $this->GetDb(); /* @var $db ADOConnection */
 
       $sql = 'UPDATE ' . $this->fields_table_name . '
@@ -627,10 +487,10 @@ class CGCalendar extends CGExtensions
       $db->Execute($sql,array($field_newname, $field_type, $field_searchable, $field_extra, $field_oldname));
       $sql = 'UPDATE ' . $this->event_field_values_table_name . ' SET field_name = ? WHERE field_name = ?';
       $db->Execute($sql,array($field_newname, $field_oldname));
-    }
+  }
 	
   function GetDayNames()
-    {
+  {
       $day_names[0] = $this->Lang('cal_sunday');
       $day_names[1] = $this->Lang('cal_monday');
       $day_names[2] = $this->Lang('cal_tuesday');
@@ -639,10 +499,10 @@ class CGCalendar extends CGExtensions
       $day_names[5] = $this->Lang('cal_friday');
       $day_names[6] = $this->Lang('cal_saturday');
       return $day_names;
-    }
+  }
 
   function GetDayShortNames()
-    {
+  {
       $day_short_names[0] = $this->Lang('cal_sun');
       $day_short_names[1] = $this->Lang('cal_mon');
       $day_short_names[2] = $this->Lang('cal_tues');
@@ -651,10 +511,10 @@ class CGCalendar extends CGExtensions
       $day_short_names[5] = $this->Lang('cal_fri');
       $day_short_names[6] = $this->Lang('cal_sat');
       return $day_short_names;
-    }
+  }
 
   function GetMonthNames()
-    {
+  {
       $month_names[1] = $this->Lang('cal_january');
       $month_names[2] = $this->Lang('cal_february');
       $month_names[3] = $this->Lang('cal_march');
@@ -679,11 +539,11 @@ class CGCalendar extends CGExtensions
       $month_names["09"] = $this->Lang('cal_september');
 
       return $month_names;
-    }
+  }
 
 
   function GetLabels()
-    {
+  {
       $lang['date'] = $this->Lang('cal_date');
       $lang['summary'] = $this->Lang('cal_summary');
 
@@ -695,42 +555,39 @@ class CGCalendar extends CGExtensions
       $lang['past_events'] = $this->Lang('cal_past_events');
       $lang['upcoming_events'] = $this->Lang('cal_upcoming_events');
       return $lang;
-    }
+  }
 
 
   function isValidFilename($filename)
-    {
+  {
       $this->LoadAdmin();
       return calendar_isValidFilename($this,$filename);
-    }
+  }
 
 
   function HandleUpload($fldname,&$error)
-    {
+  {
       $this->LoadAdmin();
       return calendar_HandleUpload($this,$fldname,$error);
-    }
+  }
 
   function GetDefaultTemplate($template)
-    {
+  {
       $fn = sprintf('orig_%s_template.tpl',$template);
-      $fn = cms_join_path(dirname(__FILE__),'templates',$fn);
+      $fn = cms_join_path(__DIR__,'templates',$fn);
       $data = @file_get_contents($fn);
       return $data;
-    }
+  }
 
   function NoBreak($string) {
     return str_replace(" ","&nbsp;",$string);
   }
 		
   function SearchResult($returnid, $event_id, $attr = '')
-    {
+  {
       $result = array();
 		  
-      if( $attr != 'event')
-	{
-	  return $result;
-	}
+      if( $attr != 'event') return $result;
 		  
       $db = $this->GetDb();
       $query = 'SELECT event_title FROM '.$this->events_table_name.' WHERE event_id = ?';
@@ -755,11 +612,11 @@ class CGCalendar extends CGExtensions
 					   'return_id'=>$returnid),
 				     '', true, '', '', $prettyurl);
       return $result;
-    }
+  }
 
 		
   function SearchReindex(&$module)
-    {
+  {
       $db = $this->GetDb();
 
       $query = 'SELECT * FROM '.$this->events_table_name.' ORDER BY event_date_start';
@@ -770,28 +627,22 @@ class CGCalendar extends CGExtensions
                      ON fd.field_name = fv.field_name AND fd.field_searchable = 1 
                   WHERE fv.event_id = ?';
   
-      while ($dbr && !$dbr->EOF)
-		{
-		  $text = $dbr->fields['event_title'].' '.$dbr->fields['event_summary'].' '.
-			$dbr->fields['event_details'];
+      while ($dbr && !$dbr->EOF) {
+		$text = $dbr->fields['event_title'].' '.$dbr->fields['event_summary'].' '.
+		  $dbr->fields['event_details'];
 
-		  $morewords = $db->GetCol($fquery,array($dbr->fields['event_id']));
-		  if( $morewords )
-			{
-			  $text .= ' '.implode(' ',$morewords);
-			}
-		  $module->AddWords($this->GetName(), $dbr->fields['event_id'], 'event', $text, NULL);
-		  
-		  $dbr->MoveNext();
-		}
-    }
+		$morewords = $db->GetCol($fquery,array($dbr->fields['event_id']));
+		if( $morewords ) $text .= ' '.implode(' ',$morewords);
+		$module->AddWords($this->GetName(), $dbr->fields['event_id'], 'event', $text, NULL);
+		$dbr->MoveNext();
+	  }
+  }
 
   function ToAbbreviatedWeekdays($data)
   {
-	if( !is_array($data) )
-	  {
-		$data = explode(',',$data);
-	  }
+	if( !is_array($data) ) {
+	  $data = explode(',',$data);
+	}
 
 	$weekdays = array(
 					  0=>'sunday',
@@ -802,33 +653,31 @@ class CGCalendar extends CGExtensions
 					  5=>'friday',
 					  6=>'saturday');
 	$result = array();
-	foreach( $data as $one )
-	  {
-		$result[] = $this->Lang('abbr_'.$weekdays[$one]);
-	  }
+	foreach( $data as $one ) {
+	  $result[] = $this->Lang('abbr_'.$weekdays[$one]);
+	}
     if( !count($result) ) return '';
 	$tmp = implode(',',$result);
 	return $tmp;
   }
 
-	// timestamp is a Unix timestamp (seconds since epoch)
-	// tzone is an time-zone offset from GMT
-	function UnixTimestampToiCal($timestamp, $tzone = 0)
-	{
-		$zulu = $timestamp + ($tzone * 3600);
-		$iCal  = date("Ymd\THis\Z", $zulu);
-		return $iCal;       
-	}
+  // timestamp is a Unix timestamp (seconds since epoch)
+  // tzone is an time-zone offset from GMT
+  function UnixTimestampToiCal($timestamp, $tzone = 0)
+  {
+	$zulu = $timestamp + ($tzone * 3600);
+	$iCal  = date("Ymd\THis\Z", $zulu);
+	return $iCal;       
+  }
 	
-	function ConvertCategoriesToString($categories)
-	{
-		$ary = array();
-		foreach ($categories as $one)
-		{
-			$ary[] = $one['category_name'];
-		}
-		return implode(',', $ary);
+  function ConvertCategoriesToString($categories)
+  {
+	$ary = array();
+	foreach ($categories as $one) {
+	  $ary[] = $one['category_name'];
 	}
-	
+	return implode(',', $ary);
+  }
+
 }; // class
-?>
+?>
\ No newline at end of file
