@@ -230,7 +230,9 @@ foreach($fields as $field)
       break;
 
     case 2:
-      $obj->field = $this->CreateTextArea(false,$id,$field_value,'field_'.$safefieldname);
+      $wysiwyg = false;
+      if( isset($field['field_extra']['wysiwyg']) ) $wysiwyg = $field['field_extra']['wysiwyg'];
+      $obj->field = $this->CreateTextArea($wysiwyg,$id,$field_value,'field_'.$safefieldname);
       break;
 
     case 3:
