@@ -41,10 +41,9 @@ if( !isset($gCms) ) exit;
 // Initialization
 //
 $thetemplate = 'myevents_'.$this->GetPreference(CGCALENDAR_PREF_DFLTMYEVENTS_TEMPLATE);
-if( isset($params['myeventstemplate'] ) )
-  {
-    $thetemplate = 'myevents_'.$params['myeventstemplate'];
-  }
+if( isset($params['myeventstemplate'] ) ) {
+  $thetemplate = 'myevents_'.$params['myeventstemplate'];
+ }
 $feu = $this->GetModuleInstance('FrontEndUsers');
 if( !is_object($feu) ) return; // no feu module.
 $feu_uid = $feu->LoggedInId();
@@ -54,31 +53,27 @@ $destpage = $returnid;
 {
   $tmp = $this->GetPreference('frontend_redirectpage','');
   $tmp = $this->ProcessTemplateFromData($tmp);
-  if( isset($params['editpage']) )
-    {
-      $tmp = trim($params['editpage']);
-    }
+  if( isset($params['editpage']) ) {
+    $tmp = trim($params['editpage']);
+  }
   $tmp = $this->resolve_alias_or_id($tmp);
-  if( $tmp )
-    {
-      $destpage = $tmp;
-    }
+  if( $tmp ) {
+    $destpage = $tmp;
+  }
 }
 
 // 
 // Get data 
 //
 $category_ids = '';
-if( isset($params['category']) && $params['category'] != '' )
-  {
-    $category = explode(',',$params['category']);
-    for( $i = 0; $i < count($category); $i++ )
-      {
-	$category[$i] = "'".trim($category[$i])."'";
-      }
-    $query = 'SELECT category_id FROM '.$this->categories_table_name.' WHERE category_name IN ('.implode(',',$category).')';
-    $category_ids = $db->GetCol($query);
+if( isset($params['category']) && $params['category'] != '' ) {
+  $category = explode(',',$params['category']);
+  for( $i = 0; $i < count($category); $i++ ) {
+    $category[$i] = "'".trim($category[$i])."'";
   }
+  $query = 'SELECT category_id FROM '.$this->categories_table_name.' WHERE category_name IN ('.implode(',',$category).')';
+  $category_ids = $db->GetCol($query);
+ }
 
 $qparms = array();
 $where  = array();
@@ -86,45 +81,39 @@ $joins  = array();
 $query = 'SELECT * FROM '.$this->events_table_name.' ev';
 $where[] = 'event_created_by = ?';
 $qparms[] = (int)$feu_uid;
-if( is_array($category_ids) && count($category_ids) > 0 )
-  {
-    $joins[] = ' LEFT JOIN '.$this->events_to_categories_table_name.' ec ON ev.event_id = ec.event_id';
-    $where[] = 'ec.category_id IN ('.implode(',',$category_ids).')';
-  }
+if( is_array($category_ids) && count($category_ids) > 0 ) {
+  $joins[] = ' LEFT JOIN '.$this->events_to_categories_table_name.' ec ON ev.event_id = ec.event_id';
+  $where[] = 'ec.category_id IN ('.implode(',',$category_ids).')';
+ }
 $order = ' ORDER BY event_modified_date';
 // build the query.
-if( count($joins) )
-  {
-    $query .= implode(' ',$joins);
-  }
-if( count($where) )
-  {
-    $query .= ' WHERE '.implode(' AND ',$where);
-  }
+if( count($joins) ) {
+  $query .= implode(' ',$joins);
+ }
+if( count($where) ) {
+  $query .= ' WHERE '.implode(' AND ',$where);
+ }
 $query .= $order;
 $data = $db->GetArray($query,$qparms);
 
 //
 // Give data to smarty
 //
-if( is_array($data) && count($data) > 0 )
-  {
-    for( $i = 0; $i < count($data); $i++ )
-      {
-	$rec =& $data[$i];
-	$parms = $params;
-	$parms['return_id'] = $returnid;
-	$parms['event_id'] = $rec['event_id'];
-	$rec['edit_url'] = $this->CreateURL($id,'addedit_event',$destpage,$parms);
-	$rec['delete_url'] = $this->CreateURL($id,'delete_event',$destpage,$parms);
-      }
-    $smarty->assign('records',$data);
+if( is_array($data) && count($data) > 0 ) {
+  for( $i = 0; $i < count($data); $i++ ) {
+    $rec =& $data[$i];
+    $parms = $params;
+    $parms['return_id'] = $returnid;
+    $parms['event_id'] = $rec['event_id'];
+    $rec['edit_url'] = $this->CreateURL($id,'addedit_event',$destpage,$parms);
+    $rec['delete_url'] = $this->CreateURL($id,'delete_event',$destpage,$parms);
   }
+  $smarty->assign('records',$data);
+ }
 $gid = $this->GetPreference('frontend_group','');
-if( $gid && $feu->MemberOfGroup($feu_uid,$gid) )
-  {
-    $smarty->assign('add_event_url',$this->CreateURL($id,'addedit_event',$returnid));
-  }
+if( $gid && $feu->MemberOfGroup($feu_uid,$gid) ) {
+  $smarty->assign('add_event_url',$this->CreateURL($id,'addedit_event',$returnid));
+ }
 
 //
 // Process the template.
