@@ -74,8 +74,7 @@ function DisplayList(&$module, $id, &$parameters, $returnid)
 	$return_link = get_parameter_value($parameters, 'return_link', 0);
 	$limit = get_parameter_value($parameters, 'limit', -1);
 	$inline = get_parameter_value($parameters,'inline',0);
-
-	$reverse = cms_to_bool(get_parameter_value($parameters, 'reverse', 'false'));
+	$reverse = get_parameter_value($parameters, 'reverse', false);
 	$sorting = ($reverse == true ? 'DESC' : 'ASC');
 
 	$use_session = isset($parameters['use_session']) ? trim($parameters['use_session']) : '';
