@@ -488,198 +488,4 @@ $lang['cal_recur_until'] = 'Wiederholen bis';
 $lang['help_template'] = '<p><strong>Name des Autors ausgeben:</strong></p>
 <code>Autor: {$event.authorname}</code>
 ';
-$lang['cal_help'] = '<h3>Hinweis:</h3>
-<p>Die Version 1.0 von Calguys Kalender ist eine Weiterentwicklung des alten Calender-Moduls. Aufgrund dessen wird es nicht zusammen mit anderen Versionen funktionieren.</p>
-<h3>Was macht dieses Modul?</h3>
-<p>Das Kalender-Modul ist dazu da, um einen Kalender mit Terminen/Ereignissen auf Ihrer Webseite anzuzeigen. Nach der Installation k&ouml;nnen Sie in der Administration &uuml;ber das Men&uuml; &bdquo;Inhalte > Kalender&ldquo; Ihre Termine/Ereignisse verwalten.</p>
-<h3>Sicherheit</h3>
-<p>Um Termine/Ereignisse hinzuf&uuml;gen, bearbeiten oder l&ouml;schen zu k&ouml;nnen, muss der Benutzer einer Gruppe mit der Berechtigung &bdquo;Modify Calendar&ldquo; angeh&ouml;ren.</p>
-<h3>Wie wird es eingesetzt ?</h3>
- <ol>
-  <li>F&uuml;gen Sie den {cms_module}-Tag in eine Seite ein. Achten Sie darauf, dass der Code nicht von anderen HTML-Tags (wie etwa <code>pre</code>,<code>code</code> oder &auml;hnlichem) eingeschlossen wird. Kontrollieren Sie den Quellcode. Der einzuf&uuml;gende Code sollte so aussehen:<br />
-   <code>{cms_module module=&quot;CGCalendar&quot;}</code> oder einfach <code>{CGCalendar}</code><br />
-   <li>Gestalten Sie den Kalender via CSS nach Ihren Vorstellungen (ein Beispiel-Stylesheet wurde Ihrer CSS-Liste mit der Installation hinzugef&uuml;gt).</li>
-   <li>Verbinden Sie dieses Stylesheet mit dem Template, welches Sie f&uuml;r die Kalender-Seite nutzen.</li>
-</ol>
-<h4>So verbinden Sie das mitgelieferte Stylesheet mit Ihrem Template:</h4>
-<ol>
-<li>Gehen Sie in der Administration in das Men&uuml; &bdquo;Layout -> Templates&ldquo;</li>
-<li>Klicken Sie anschlie&szlig;end das CSS-Icon (Stylesheet mit dem Template verkn&uuml;pfen) in der Zeile des gew&uuml;nschten Templates</li>
-<li>W&auml;hlen Sie dann &bdquo;Calendar CSS example&ldquo; im Listenfeldmen&uuml; aus.</li>
-<li>Klicken Sie nun auf den Button &bdquo;Neues Stylesheet hinzuf&uuml;gen&ldquo;.</li>
-</ol>
-<h3>Welche Parameter k&ouml;nnen verwendet werden?</h3>
-<table border=&quot;0&quot; cellpadding=&quot;3&quot; cellspacing=&quot;0&quot;>
-  <tr>
-     <th>display</th>
-     <td>Akzeptierte Werte:
-         <ul>
-             <li> &bdquo;calendar&ldquo; &ndash; zeigt die Termine/Ereignisse des aktuellen Monats im traditionellen Raster an. Zeigt Links zum vorherigen und kommenden Monat</li>
-             <li>&bdquo;event&ldquo; &ndash; zeigt die ausf&uuml;hrlichen Informationen f&uuml;r ein Ereignis/Termin an. Um diesen Modus zu verwenden, muss die ID des Ereignisses/Termins angegeben werden (Parameter event_id).</li>
-             <li>&bdquo;list&ldquo; &ndash; zeigt die Termine/Ereignisse des aktuellen Monats als Liste an. Zeigt Links zum vorherigen und kommenden Monat</li>
-             <li> &bdquo;yearlist&ldquo; &ndash; zeigt die Termine/Ereignisse des aktuellen Jahres als Liste an. Zeigt Links zum vorherigen und kommenden Jahr</li>
-             <li>&bdquo;pastlist&ldquo; &ndash; zeigt alle vergangenen Termine/Ereignisse an.  Enth&auml;lt keine Links zum Bl&auml;ttern</li>
-             <li>&bdquo;upcominglist&ldquo; &ndash; zeigt alle bevorstehenden Termine/Ereignisse an. Enth&auml;lt keine Links zum Bl&auml;ttern.</li>
-         </ul>
-	    Standard ist &bdquo;calendar&ldquo;. <em>(optional)</em>
-      </td>
-   </tr>
-
-   <tr>
-	<th>category</th>
-	<td>zeigt nur Eintr&auml;ge f&uuml;r diese Kategorie an. Ohne Eintrag werden alle Kategorien angezeigt. Sollen mehrere
-	Kategorien angezeigt werden, sind diese mit Kommata getrennt anzugeben. <em>(optional)</em></td>
-		</tr>
-
-   <tr>
-	<th>month</th>
-	<td>zeigt die Eintr&auml;ge f&uuml;r einen bestimmten Monat. Falls das Jahr nicht definiert wurde, wird das aktuelle Jahr
-	verwendet. Diese Option ist nur bei den Einstellungen &bdquo;list&ldquo; oder &bdquo;calendar&ldquo; verf&uuml;gbar. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>year</th>
-	<td>zeigt die Eintr&auml;ge f&uuml;r ein bestimmtes Jahr.
-		Diese Option ist nur bei den Einstellungen &bdquo;list&ldquo; oder &bdquo;calendar&ldquo; verf&uuml;gbar. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>limit</th>
-	<td>bestimmt die maximale Anzahl der angezeigten Termine/Ereignisse. Diese Option ist nur bei den Einstellungen &bdquo;list&ldquo;, &bdquo;pastlist&ldquo; oder &bdquo;upcominglist&ldquo; verf&uuml;gbar. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>first_day_of_week</th>
-	<td>legt den ersten Tag der im Kalender angezeigten Woche mit einer Ziffer zwischen 0 und 6 fest (0 = Sonntag). Standard ist 1 (Montag).
-	Diese Option ist nur bei der Einstellung &bdquo;calendar&ldquo; verf&uuml;gbar. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>summaries</th>
-	<td>Wird dieser Wert auf 1 gesetzt, wird im &bdquo;calendar&ldquo;-Modus eine Zusammenfassung der Informationen zu dem Termin angezeigt. Mit 0 wird dies ausgeschaltet. Standard ist 1. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>detail</th>
-	<td>Wird dieser Wert auf 1 gesetzt, werden im &bdquo;list&ldquo;-Modus detaillierte Informationen zu dem Termin/Ereignis angezeigt.  Mit 0 wird dies ausgeschaltet. Standard ist 0. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>use_session</th>
-	<td>verwendet eine Sitzungsvariable, um den aktuellen Monat des Kalenders zwischenzuspeichern. Standard ist true. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>compact_view</th>
-	<td>Setzen Sie diesen Wert auf 1, um die Navigationslinks zu verbergen. Dies ist insbesondere dann n&uuml;tzlich, wenn nur die Termine/Ereignisse des aktuellen Monats auf der Webseite angezeigt werden sollen. Standard ist 0. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>inline</th>
-	<td>Setzen Sie diesen Wert auf 0, um die Termin-/Ereignis-Links im Inline-Modus anzuzeigen (der Seiteninhalt wird durch die Termine/Ereignisse ersetzt).  Standard ist 1. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>reverse</th>
-	<td>Setzen Sie diesen Wert auf true, um die Termine/Ereignisse in zeitlich umgekehrter Reihenfolge anzuzeigen. Diese Option ist nur bei den Einstellungen list, past und upcominglist verf&uuml;gbar. Standard ist false. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>detailpage=&quot;pagealias&quot;</th>
-	<td>Hiermit k&ouml;nnen Sie eine Seite festlegen, auf der die Details zu den Terminen/Ereignissen angezeigt werden sollen. Dies kann ein Seiten-Alias oder auch eine ID sein. Damit wird es m&ouml;glich, die Details mit einem anderen Template als die Zusammenfassung anzeigen zu lassen. Standard ist die aktuelle Seite. <em>(optional)</em></td>
-    </tr>
-
-   <tr>
-	<th>columns</th>
-	<td>Mit dieser Einstellung l&auml;sst sich eine spaltenweise Ausgabe der Ereignisse realisieren. M&ouml;gliche Werte sind 1/2. Standard ist 1. Funktioniert nur in den Modi upcominglist und pastlist. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>columnstyle</th>
-	<td>Wenn der Parameter columns=&quot;2&quot; ist, legt dieser Parameter fest, ob die Ereignisse horizontal (0) oder vertikal (1) geordnet werden. Standard ist 1. <em>(optional)</em></td>
-   </tr>
-
-   <tr>
-	<th>currentcolumn</th>
-	<td>Wenn der Parameter columns=&quot;2&quot; ist, kann &uuml;ber diesen Parameter festgelegt werden, ob die Inhalte der Spalte 1 oder 2 angezeigt werden. M&ouml;gliche Werte sind 1/2. Standard ist 1. <em>(optional)</em></td>
-   </tr>
-
-  <tr>
-     <th>event_id</th>
-     <td>In Verbindung mit dem Modus display=&quot;event&quot; k&ouml;nnen mit diesem Parameter Informationen zu einem bestimmten Termin/Ereignis angezeigt werden.</td>
-  </tr>
-
-  <tr>
-     <th>limit</th>
-     <td>Bei Verwendung mit der Listen-Anzeige erm&ouml;glicht dieser Parameter die Vorgabe, wie viele Ereignisse pro Seite angezeigt werden sollen. Wird dieser Wert &uuml;berschritten, erfolgt ein Umbruch auf eine neue Seite.</td>
-  </tr>
-
-  <tr>
-     <th>calendartemplate</th>
-     <td>Bei Verwendung des Kalender-Modus kann &uuml;ber diesen Parameter ein Template aus der Liste festgelegt werden, welche f&uuml;r die Anzeige des Kalenders verwendet werden soll (abweichend von dem festgelegten Standard-Template).</td>
-  </tr>
-
-  <tr>
-     <th>eventtemplate</th>
-     <td>Mit diesem Parameter kann ein Template aus der Liste festgelegt werden, welches f&uuml;r die Anzeige des Ereignisses verwendet werden soll (abweichend von dem festgelegten Standard-Template).</td>
-  </tr>
-
-   <tr>
-	<th>listtemplate</th>
-	<td>Bei Verwendung des &bdquo;list&ldquo;-Modus kann &uuml;ber diesen Parameter festgelegt werden, welches Template f&uuml;r die Listen-Anzeige verwendet werden soll (abweichend von dem festgelegten Standard-Template).</td>
-   </tr>
-
-   <tr>
-	<th>upcominglisttemplate</th>
-	<td>Bei Verwendung des &bdquo;upcominglist&ldquo;-Modus kann &uuml;ber diesen Parameter festgelegt werden, welches Template f&uuml;r die Anzeige zuk&uuml;nftiger Termine/Ereignisse verwendet wird (abweichend von dem festgelegten Standard-Template).</td>
-   </tr>
-
-  <tr>
-     <th>moretext</th>
-     <td>Wird in den verschiedenen Zusammenfassungs-Templates verwendet. &Uuml;ber diesen Parameter kann ein Text f&uuml;r den Link festgelegt werden, der auf die Seite mit der Detail-Anzeige verweist.</td>
-  </tr>
-</table>
-
-<h3>Benutzerdefinierte Felder</h3>
-<p>Es ist au&szlig;erdem m&ouml;glich, benutzerdefinierte Felder zu erstellen, die in der Modul-Administration &uuml;ber die Registerkarte &bdquo;Felder&ldquo; jedem Ereignis zugeordnet werden k&ouml;nnen. Entweder ein oder mehrere Felder definieren die Werte des Feldes f&uuml;r jedes Ereignis. Diese Felder k&ouml;nnen dann &uuml;ber den Registerkarte &bdquo;Ereignisse&ldquo; gef&uuml;llt werden. Die Werte dieser Felder k&ouml;nnen &uuml;ber den Syntax event.field.fieldname in den Templates ausgegeben werden. Ein Tipp: geben Sie {debug} in Ihr Template ein, um alle Daten zu sehen, die an das Template &uuml;bergeben werden.</p>
-
-<h3>Beispiele</h3>
-<h4>Ein Beispiel, wie Sie Kommentare f&uuml;r Termine/Ereignisse verwenden k&ouml;nnen:</h4>
-<p>Installieren Sie das Comments-Modul und rufen es wie folgt im jeweiligen Ereignis-Template auf:</p>
-<pre><code>{cms_module module=&#039;comments&#039; modulename=&#039;CGCalendar&#039; pageid=$event.event_id}</code></pre>
-
-<h3>Support</h3>
-<p>Dieses Modul beinhaltet keinen kommerziellen Support. Sie k&ouml;nnen jedoch &uuml;ber folgende M&ouml;glichkeiten Hilfe zu dem Modul erhalten:</p>
-<ul>
-<li>F&uuml;r die letzte Version dieses Moduls, FAQs, dem Versand eines Fehlerreports oder dem Kauf kommerziellen Supports besuchen Sie bitte die Projektseite unter <a href="http://dev.cmsmadesimple.org">dev.cmsmadesimple.org</a>.</li>
-<li>Eine weitere Diskussion zu diesem Modul ist auch in den Foren von <a href="http://forum.cmsmadesimple.org">CMS Made Simple</a> zu finden.</li>
-<li>Der Autor calguy1000, ist h&auml;ufig im <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a> zu finden.</li>
-<li>Letztlich erreichen sie den Autor auch &uuml;ber eine direkte Email.</li>  
-</ul>
-<p>Nach der GPL wird diese Software so ver&ouml;ffentlicht, wie sie ist. Bitte lesen Sie den Lizenztext f&uuml;r den vollen Haftungsausschluss.</p>
-
-<h3>Copyright und Lizenz</h3>
-<p>Copyright &copy; 2008, Robert Campbell <a href="mailto:calguy1000@hotmail.com">calguy1000@hotmail.com</a>. Alle Rechte vorbehalten.</p>
-<p>Dieses Modul wurde unter der <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a> ver&ouml;ffentlicht. Sie m&uuml;ssen dieser Lizenz zustimmen, bevor Sie das Modul verwenden.</p>
-<p>This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.</p>
-<p>However, as a special exception to the GPL, this software is distributed
-as an addon module to CMS Made Simple.  You may not use this software
-in any Non GPL version of CMS Made simple, or in any version of CMS
-Made simple that does not indicate clearly and obviously in its admin 
-section that the site was built with CMS Made simple.</p>
-<p>This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
-$lang['utma'] = '156861353.566816069.1326487945.1326487945.1326569148.2';
-$lang['utmz'] = '156861353.1326487945.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
-?>
\ No newline at end of file
+?>
